@@ -5,13 +5,13 @@ import json
 from typing import Any, Callable
 from quickjs import Context
 
-from thresult import Ok, Err
+from thresult import Ok, Err, WrappedBase
 
 
 QuickJSResult: type = Ok[Any] | Err[str]
 
 
-class QuickJS:
+class QuickJS(WrappedBase):
     '''
     A class to handle context for JavaScript and Python code
     '''
